@@ -1270,9 +1270,7 @@ mod tests {
             object_properties: PropertiesMap::default(),
             comment_links: BTreeSet::default(),
             forward_name: None,
-            forward_direction: None,
             backward_name: None,
-            backward_direction: None,
             color: None,
             text_color: None,
             sort_order: None,
@@ -1318,9 +1316,7 @@ mod tests {
             object_properties: PropertiesMap::default(),
             comment_links: BTreeSet::default(),
             forward_name: Some("Hôtels - Hôtels".to_string()),
-            forward_direction: Some("OIF:SA:4:126".to_string()),
             backward_name: Some("Hôtels - Hôtels".to_string()),
-            backward_direction: Some("OIF:SA:4:126".to_string()),
             color: Some(objects::Rgb {
                 red: 155,
                 green: 12,
