@@ -601,9 +601,7 @@ mod tests {
                 object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 forward_name: Some("Hôtels - Hôtels".to_string()),
-                forward_direction: None,
                 backward_name: Some("Hôtels - Hôtels".to_string()),
-                backward_direction: None,
                 color: Some(Rgb {
                     red: 155,
                     green: 12,
@@ -629,9 +627,7 @@ mod tests {
                 object_properties: PropertiesMap::default(),
                 comment_links: CommentLinksT::default(),
                 forward_name: None,
-                forward_direction: None,
                 backward_name: None,
-                backward_direction: None,
                 color: None,
                 text_color: None,
                 sort_order: None,
@@ -1136,9 +1132,7 @@ mod tests {
             )],
             comment_links: btree_set_from_vec(vec!["c:1".to_string(), "c:2".to_string()]),
             forward_name: None,
-            forward_direction: None,
             backward_name: None,
-            backward_direction: None,
             color: None,
             text_color: None,
             sort_order: None,
